==> haskell-coinbase-pro-0.9.3.2-426-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-1NhYeIdSZeb42Qt6mjzrXm
key:                  coinbase-pro-0.9.3.2-1NhYeIdSZeb42Qt6mjzrXm
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  d81f9b053289f5f6e82acd5622234386
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-1NhYeIdSZeb42Qt6mjzrXm
depends:
    HsOpenSSL-0.11.7.9-7b2YaIo8nxa5WFX252B8AR
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-casing-0.2.0.0-CHKI9jgLm75DTsCBp5yLrQ
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-5QYVWJr24zH1Zlsr0wVxCr exceptions-0.10.7
    http-api-data-0.6.1-6b8SlzeGz22trXyYobem
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-streams-0.8.9.9-Gvff5xvlkraA0wPz4XHETT
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    io-streams-1.5.2.2-6dLtg5IQso2LoK2aAZRuxZ
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    servant-0.20.3.0-EGizVGIAZ794yRWvR5V6rz
    servant-client-0.20.3.0-H9kkBZ4IV3U4OeAaTOKfNI
    servant-client-core-0.20.3.0-IG567hdFs9P773jrRHbW0f
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB
    tasty-hunit-0.10.2-96pg6B929I9E8nnywjEniv text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-E7ae8BgkJxoJ20J9gQ4bna
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-1.3.16-8QEdndSNqxbGO60kyYYcsS
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    websockets-0.12.7.3-IxRNJzBRjoIAVwGwpWypj
    wuss-2.0.1.6-1KR5qui0UJDA9n6hGHRT1J

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-428-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-Ba1GImaTeI8Hk1Vc9by7DW
key:                  coinbase-pro-0.9.3.2-Ba1GImaTeI8Hk1Vc9by7DW
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  809beec031a067c9739c3ace00e28ad4
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-Ba1GImaTeI8Hk1Vc9by7DW
depends:
    HsOpenSSL-0.11.7.9-2SKo10lXPac4Lj4rrqqeUn
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    aeson-casing-0.2.0.0-2Fbwj5jyGJJ5XoQVszJOLf
    async-2.2.5-BOONqED6PxbDsY8XxcvMc4 base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-IdvHmj4QYX5GnwcbmzszEm exceptions-0.10.7
    http-api-data-0.6.1-5scq1iPo1rG2PjoFBDCc52
    http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
    http-client-tls-0.3.6.4-ILttD7UGaFL2zbr7B8I43g
    http-streams-0.8.9.9-JtZF8xHPmRr1ojyZ04apZx
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    io-streams-1.5.2.2-GJoryvvGfU1C1jRwIClxDx
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    servant-0.20.3.0-ERMPpkFtLywKa6wFBgXbYc
    servant-client-0.20.3.0-H8EwQt1tF7VBmKDs451vhE
    servant-client-core-0.20.3.0-6axro3UJOUD4p3Bzm9QWsp
    tasty-1.5.2-9G3Kf1f0lGYDWNQy5BbNrN
    tasty-hunit-0.10.2-IM2Egl7oguPC2MIxuBFD1F text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-1TYJKxYcOhG9RLDMGiAzB5
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    uuid-1.3.16-1rdJ16rKpapCuGGJEV1Hir
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6
    websockets-0.12.7.3-2spokc2S1282Q6F8NCy0hy
    wuss-2.0.1.6-FBhGzX8Fc5FAWDCzxmq9bx

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
